@@ -75,6 +75,7 @@
 #include <QtCharts/qpielegendmarker.h>
 #include <QtCharts/qareaseries.h>
 #include <QtCharts/qvpiemodelmapper.h>
+#include <QtCharts/qxyseries.h>
 #include <QtCharts/qboxset.h>
 #include <QtCharts/qchartview.h>
 #include <QtCharts/qvboxplotmodelmapper.h>
@@ -193,8 +194,9 @@ enum : int {
     SBK_QVALUEAXIS_IDX                                       = 65,
     SBK_QXYLEGENDMARKER_IDX                                  = 67,
     SBK_QXYMODELMAPPER_IDX                                   = 68,
+    SBK_QXYSERIES_POINTCONFIGURATION_IDX                     = 70,
     SBK_QXYSERIES_IDX                                        = 69,
-    SBK_QtCharts_IDX_COUNT                                   = 70
+    SBK_QtCharts_IDX_COUNT                                   = 71
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtChartsTypes;
@@ -219,14 +221,16 @@ enum : int {
     SBK_QTCHARTS_QLIST_INT_IDX                               = 9, // QList<int >
     SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF >
     SBK_QTCHARTS_QPAIR_QREAL_QREAL_IDX                       = 11, // QPair<qreal,qreal >
-    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 12, // QList<QPieSlice* >
-    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 13, // QList<QCandlestickSet* >
-    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 14, // QList<QBoxSet* >
-    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 15, // QList<QBarSet* >
-    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 16, // QList<QVariant >
-    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 17, // QList<QString >
-    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 18, // QMap<QString,QVariant >
-    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 19
+    SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 12, // QHash<QXYSeries::PointConfiguration,QVariant >
+    SBK_QTCHARTS_QHASH_INT_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 13, // QHash<int,QHash< QXYSeries::PointConfiguration,QVariant > >
+    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 14, // QList<QPieSlice* >
+    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 15, // QList<QCandlestickSet* >
+    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 16, // QList<QBoxSet* >
+    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 17, // QList<QBarSet* >
+    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 18, // QList<QVariant >
+    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 19, // QList<QString >
+    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 20, // QMap<QString,QVariant >
+    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 21
 };
 // Macros for type check
 
@@ -305,6 +309,7 @@ template<> inline PyTypeObject *SbkType< ::QValueAxis::TickType >() { return Sbk
 template<> inline PyTypeObject *SbkType< ::QValueAxis >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QVALUEAXIS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QXYLegendMarker >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QXYLEGENDMARKER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QXYModelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QXYMODELMAPPER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QXYSeries::PointConfiguration >() { return SbkPySide6_QtChartsTypes[SBK_QXYSERIES_POINTCONFIGURATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QXYSeries >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QXYSERIES_IDX]); }
 QT_WARNING_POP
 
