@@ -4,10 +4,10 @@ from pathlib import Path
 from textwrap import dedent
 
 __all__ = list("Qt" + body for body in
-    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;OpenGL;OpenGLWidgets;Qml;Quick;QuickControls2;QuickWidgets;Scxml;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;UiTools;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
+    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;NetworkAuth;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebEngineCore;WebEngineWidgets;WebEngineQuick;WebSockets;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.1.2"
-__version_info__ = (6, 1, 2, "", "")
+__version__ = "6.2.3"
+__version_info__ = (6, 2, 3, "", "")
 
 
 def _additional_dll_directories(package_dir):
